%% Proceedings 2PA FCA
close all; format compact; keep pphome; % clean up 
%% Set parameter values

% Physical parameters
d = 0.025; 
sigma = 0.5; 
mu = 1;
v = 190;
skal = 0.05;  % auxillary parameter

% Grid parameters
temp = 10;
x_number = 4*1e2;
y_number = 4*1e2;
A_number = temp*1e2;

save_plot = true; % Save plots 

%% Define functions and instability matrix

ts_maxgersch = @(r,Delta) 1/(4*r*(1+skal))*(sqrt(r^2+1-Delta^2)-2*r)^2;
xi1 = @(r,ts,Delta) (sqrt(r^2+1-Delta) - 2*r - sqrt((sqrt(r^2+1-Delta^2)-2*r)^2 - 4*(1+skal)*r*ts))/(2*r*ts);
xi2 = @(r,ts,Delta) (sqrt(r^2+1-Delta) - 2*r + sqrt((sqrt(r^2+1-Delta^2)-2*r)^2 - 4*(1+skal)*r*ts))/(2*r*ts);
f = @(A, r, ts) (1+ r*A + r*ts*A^2)^2*A;


lambda_1 = @(A,r,ts,Delta) -1 + A*(sqrt(r^2+1-Delta^2)-2*r) - r*ts*A^2;
lambda_2 = @(A,r,ts,Delta) -1 - A*(sqrt(r^2+1-Delta^2) + 2*r) - r*ts*A^2;
c = @(A,r,ts) 1i*v*sqrt(A/d) + sigma/ts;
w_1 = @(A,r,ts,Delta) 2*skal^(-1)*sigma*r*A^2/(r^2+1-Delta^2)*((r-mu*(1+Delta))*sqrt(1+r^2-Delta^2) - (1+r^2-Delta^2));
w_2 = @(A,r,ts,Delta) 2*skal^(-1)*sigma*r*A^2/(r^2+1-Delta^2)*((mu*(1+Delta)-r)*sqrt(1+r^2-Delta^2) - (1+r^2-Delta^2));
M = @(A,r,ts,Delta) [lambda_1(A,r,ts,Delta), 0, skal;
    0, lambda_2(A,r,ts,Delta), skal;
    w_1(A,r,ts,Delta), w_2(A,r,ts,Delta), -c(A,r,ts)];


%% Compute instability region of Corollary 1

x_gersch = logspace(-1,0,x_number);
y_gersch = logspace(-2,2,y_number);

[X_gersch, Y_gersch] = meshgrid(x_gersch,y_gersch);
[x_max, y_max] = size(X_gersch);
Z1 = nan*ones(x_max,y_max);
for i = 1:x_max
    for j = 1:y_max
        r = X_gersch(i,j); ts = Y_gersch(i,j);
        if r < 1/sqrt(3)
            if ts < ts_maxgersch(r,0)
                a = ceil(sqrt(xi1(r,ts,0)/d));
%                 A = (r- sqrt((1+eps)*r*ts))/ts*r;
%                 k_star = round(sqrt(A/d)); Delta = d*k_star^2/A-1;
                A = a^2*d;
                if xi1(r,ts,0) < A && A < xi2(r,ts,0)
                if (lambda_1(A, r, ts,0) + sigma/ts)^2 + v^2*A/d ...
                        > (skal + abs(w_1(A, r, ts,0)) + abs(w_2(A, r, ts,0)))^2
                    if ts < ts_maxgersch(r,0)
                        F = f(A, r, ts);
                        if F < 30
                            Z1(i,j) = F;
                        end
                    end
                end
                end
            end
        end
    end
end




%% Compute instability region of L_{2,k^*}

x_matrix = logspace(-1,0,x_number);
y_matrix = logspace(-2,2,y_number);

[X_matrix, Y_matrix] = meshgrid(x_matrix, y_matrix);
[x_max, y_max] = size(X_matrix);
Z2 = nan*ones(x_max,y_max);

A_max = 25;
A_rang = linspace(1, A_max, A_number);
for i = 1:x_max
    for j = 1:y_max
        r = X_matrix(i,j); ts = Y_matrix(i,j);
        k = 1;
        gain = -1;
        while (k <= A_number) && (gain <= 0)
            A = A_rang(k);
            k_star = round(sqrt(A/d)); Delta = d*k_star^2/A-1;
            gain_vec = eig(M(A,r,ts,Delta));
            gain_vec_real = real(gain_vec);
            gain = max(gain_vec_real);
            k = k+1;
        end
        if gain > 0
            if f(A_rang(k-1),r,ts) < 30
                Z2(i,j) = f(A_rang(k-1),r,ts);
            end
        end
    end
end


%% Compute difference of instability regions

Z3 = nan*ones(x_max,y_max);

for i = 1:x_max
    for j = 1:y_max
        if isnan(Z1(i,j)) && not(isnan(Z2(i,j)))
            Z3(i,j)= 1000;
        end
        if not(isnan(Z1(i,j))) && not(isnan(Z2(i,j)))
            Z3(i,j) = Z1(i,j)-Z2(i,j);
        end
        if not(isnan(Z1(i,j))) && isnan(Z2(i,j))
            Z3(i,j)= -1000;
        end
    end
end

%% Plots

fontsize = 40;

% for labels
k_rtresh = (log10(1/sqrt(3)) + 1)*(x_number - 1) + 1;
k_rtresh = floor(k_rtresh);
k_10_m1 = (-1 + 2)* (y_number-1)/4 + 1;
k_10_0 = 2*(y_number-1)/4 + 1;
k_10_p1 = 3*(y_number-1)/4 + 1;


f1 = figure(1);f1.WindowState = 'maximized';clf;
hold on;
set(gca,'TickLabelInterpreter','latex');
contourf(Z1,[1 5 10 15 20 25]);
ax = gca(f1);
ax.FontSize = fontsize;
xlabel('$r$', 'fontsize', fontsize, 'interpreter', 'latex')
ylabel('$\sigma \tau$', 'fontsize', fontsize, 'interpreter', 'latex')
cb = colorbar;
set(cb, 'TickLabelInterpreter','latex');
ylabel(cb,'$f_{thres}^2$', 'fontsize', fontsize,'interpreter', 'latex');
xticks([1 k_rtresh x_number]);
xticklabels({'$10^{-1}$','$1/\sqrt{3}$','$10^{0}$'});
yticks([1 k_10_m1 k_10_0 k_10_p1 y_number])
yticklabels({'$10^{-2}$','$10^{-1}$','$10^{0}$','$10^{1}$','$10^{2}$'})
pbaspect([4 3 1]);
hold off;

if save_plot
    exportgraphics(gca,'MI_Theorem.png');
end


f2= figure(2);f2.WindowState = 'maximized';clf;
hold on;
set(gca,'TickLabelInterpreter','latex');
contourf(Z2,[1 5 10 15 20 25])
ax = gca(f2);
ax.FontSize = fontsize;
xlabel('$r$', 'fontsize', fontsize, 'interpreter', 'latex')
ylabel('$\sigma \tau$', 'fontsize', fontsize, 'interpreter', 'latex')
cb = colorbar;
set(cb, 'TickLabelInterpreter','latex');
ylabel(cb,'$f_{num}^2$', 'fontsize', fontsize,'interpreter', 'latex');
xticks([1 k_rtresh x_number]);
xticklabels({'$10^{-1}$','$1/\sqrt{3}$','$10^{0}$'});
yticks([1 k_10_m1 k_10_0 k_10_p1 y_number])
yticklabels({'$10^{-2}$','$10^{-1}$','$10^{0}$','$10^{1}$','$10^{2}$'})
pbaspect([4 3 1]);
hold off;

if save_plot
    exportgraphics(gca,'MI_Numerik.png');
end

f3 = figure(3);f3.WindowState = 'maximized';clf;
hold on;
set(gca,'TickLabelInterpreter','latex');
contourf(Z3,[0 1 5 10]);
ax = gca(f3);
ax.FontSize = fontsize;
xlabel('$r$', 'fontsize', fontsize, 'interpreter', 'latex')
ylabel('$\sigma \tau$', 'fontsize', fontsize, 'interpreter', 'latex')
cb = colorbar;
set(cb, 'TickLabelInterpreter','latex');
ylabel(cb,'$f_{thres}^2-f_{num}^2$', 'fontsize', fontsize,'interpreter', 'latex');
xticks([1 k_rtresh x_number]);
xticklabels({'$10^{-1}$','$1/\sqrt{3}$','$10^{0}$'});
yticks([1 k_10_m1 k_10_0 k_10_p1 y_number])
yticklabels({'$10^{-2}$','$10^{-1}$','$10^{0}$','$10^{1}$','$10^{2}$'})
pbaspect([4 3 1]);
hold off;

if save_plot
    exportgraphics(gca,'MI_Differenz.png');
end


%% save files and move to figure folder

if save_plot
    movefile MI_Theorem.png ../figures/
    movefile MI_Numerik.png ../figures/
    movefile MI_Differenz.png ../figures/
end

cd ..