%% Plots
save_plots = 1;
x=getpte(p); x=x'; 
s = 322; % shift solution (translational invariance)
Fontsize = 35;

%% Branch plots

figure140 =figure(140);figure140.WindowState = 'maximized';clf;
p = loadp('sigma_cont','pt36');
plot(p.branch(12,:),p.branch(11,:),'-','Color',[0,0,0],'LineWidth',3); hold on;
plot(p.branch(12,1),p.branch(11,1),'o','MarkerSize',30,'Color',[0 0 0],'LineWidth',3);
plot(p.branch(12,9),p.branch(11,9),'o','MarkerSize',30,'Color',[0 0 0],'LineWidth',3);
p = loadp('sigma_cont-','pt10');
plot(p.branch(12,:),p.branch(11,:),'-','Color',[0,0,0],'LineWidth',3);
plot(p.branch(12,9),p.branch(11,9),'o','MarkerSize',30,'Color',[0 0 0],'LineWidth',3);
set(gca,'FontSize', Fontsize);
set(gca,'TickLabelInterpreter','latex');
xlabel('$\mu$','Interpreter', 'latex');
ylabel('$\sigma$','Interpreter', 'latex');
xlim([-0.1,0.2]);
% ylim([0.8,27]);
pbaspect([4 3 1])
hold off;
if save_plots
    exportgraphics(gca,'bif_sigma_mu.png');
end

%% Solution plots

clear u U N u1 u2
p = loadp('sigma_cont','pt0'); U(:,1)=p.u; n=p.np;
u(:,1)=p.mat.fill*U(1:p.nu,1); % extract param., extend sol
u1(:,1)=u(1:n,1); u2(:,1)=u(n+1:2*n,1); 
p = loadp('sigma_cont','pt8'); U(:,2)=p.u;
u(:,2)=p.mat.fill*U(1:p.nu,2); % extract param., extend sol
u1(:,2)=u(1:n,2); u2(:,2)=u(n+1:2*n,2);
p = loadp('sigma_cont-','pt8'); U(:,3)=p.u;
u(:,3)=p.mat.fill*U(1:p.nu,3); % extract param., extend sol
u1(:,3)=u(1:n,3); u2(:,3)=u(n+1:2*n,3);
s=-190;
u1 = circshift(u1,s,1); u2 = circshift(u2,s,1);

% Compute N via integration
N=zeros(n,3);
h=2*pi/(n-1); % mesh size
for k = 1:3

u4=(u1(:,k).^2+u2(:,k).^2).^2; tv=par(7)*par(8); rdv = par(4)/par(8); % Abkuerzungen

I = 0;
for i=2:n-1
    I = I + u4(i)*exp(x(i)/tv);
end

I = h/(exp(2*pi/tv) - 1)*( I + 0.5*u4(1)*(exp(x(1)/tv) + exp(x(n)/tv)) );

N(1,k) = rdv*I;
N(2,k) = rdv*exp(-x(2)/tv)*( I + h*0.5*(u4(1)*exp(x(1)/tv) + u4(2)*exp(x(2)/tv)) );
N(n,k) = rdv*I;
for i=3:n-1
    N(i,k) = 0.5*(u4(1)*exp(x(1)/tv) + u4(i)*exp(x(i)/tv));
    for j = 2:i-1
        N(i,k) = N(i,k) + u4(j)*exp(x(j)/tv);
    end
    N(i,k) = h * N(i,k);
    N(i,k) = rdv*exp(-x(i)/tv)*(I + N(i,k));
end
end

%% Start generating plots

figure141 = figure(141);figure141.WindowState = 'maximized';clf;
plot(x,u1(:,1).^2+u2(:,1).^2,'-','Color',[0 0 1],'LineWidth',6); hold on;
plot(x,50*N(:,1),'-','Color',[1 0 1],'LineWidth',6);
set(gca,'FontSize', Fontsize*2,'XTick',[0 pi 2*pi],'XTickLabel',{'$0$','$\pi$','$2\pi$'});
set(gca,'TickLabelInterpreter','latex');
xlabel('$x$','Interpreter', 'latex');
ylabel('$|a|^2$','Interpreter', 'latex');
xlim([0,2*pi]);
ylim([0,9]);
pbaspect([4 3 1]);
annotation(figure141,'textbox',...
     [0.565104166666667 0.375947042479073 0.109799699938305 0.0726510883620482],...
    'Color',[1 0 1],...
    'String',{'$50 \times n$'},...
    'LineWidth',3,...
    'Interpreter','latex',...
    'FontSize',Fontsize*2,...
    'EdgeColor',[1 1 1]);
hold off;
if save_plots
    exportgraphics(gca,'solution_bf.png');
end

figure142 = figure(142);figure142.WindowState = 'maximized';clf;
plot(x,u1(:,2).^2+u2(:,2).^2,'-','Color',[0 0 1],'LineWidth',6);hold on;
plot(x,50*N(:,2),'-','Color',[1 0 1],'LineWidth',6);
set(gca,'FontSize', Fontsize*2,'XTick',[0 pi 2*pi],'XTickLabel',{'$0$','$\pi$','$2\pi$'});
set(gca,'TickLabelInterpreter','latex');
xlabel('$x$','Interpreter', 'latex');
ylabel('$|a|^2$','Interpreter', 'latex');
xlim([0,2*pi]);
ylim([0,9]);
annotation(figure142,'textbox',...
     [0.565104166666667 0.375947042479073 0.109799699938305 0.0726510883620482],...
    'Color',[1 0 1],...
    'String',{'$50 \times n$'},...
    'LineWidth',3,...
    'Interpreter','latex',...
    'FontSize',Fontsize*2,...
    'EdgeColor',[1 1 1]);
pbaspect([4 3 1]);
hold off;
if save_plots
    exportgraphics(gca,'solution_+.png');
end

figure143 = figure(143);figure143.WindowState = 'maximized';clf;
plot(x,u1(:,3).^2+u2(:,3).^2,'-','Color',[0 0 1],'LineWidth',6);hold on;
plot(x,50*N(:,3),'-','Color',[1 0 1],'LineWidth',6);
set(gca,'FontSize', Fontsize*2,'XTick',[0 pi 2*pi],'XTickLabel',{'$0$','$\pi$','$2\pi$'});
set(gca,'TickLabelInterpreter','latex');
xlabel('$x$','Interpreter', 'latex');
ylabel('$|a|^2$','Interpreter', 'latex');
xlim([0,2*pi]);
ylim([0,9]);
annotation(figure143,'textbox',...
     [0.565104166666667 0.375947042479073 0.109799699938305 0.0726510883620482],...
    'Color',[1 0 1],...
    'String',{'$50 \times n$'},...
    'LineWidth',3,...
    'Interpreter','latex',...
    'FontSize',Fontsize*2,...
    'EdgeColor',[1 1 1]);
pbaspect([4 3 1]);
hold off;
if save_plots
    exportgraphics(gca,'solution_-.png');
end

 movefile bif_sigma_mu.png ../figures/
 movefile solution_bf.png ../figures/
 movefile solution_+.png ../figures/
 movefile solution_-.png ../figures/

 cd ..